const colors = [
  '#4e79a7', '#f28e2c', '#e15759', '#76b7b2',
  '#59a14f', '#edc949', '#af7aa1', '#ff9da7',
  '#9c755f', '#bab0ac'
];

let piChart;
let chartData = Array(10).fill(0);
let isRunning = false;
let animationFrame;

const ctx = document.getElementById('piChart').getContext('2d');
piChart = new Chart(ctx, {
  type: 'pie',
  data: {
    labels: Array.from({length: 10}, (_, i) => i.toString()),
    datasets: [{
      data: chartData,
      backgroundColor: colors,
      borderWidth: 0
    }]
  },
  options: {
    responsive: true,
    maintainAspectRatio: false,
    animation: {
      duration: 200,
      easing: 'easeOutQuart'
    },
    plugins: {
      legend: {
        position: 'bottom',
        labels: {
          boxWidth: 20,
          padding: 15
        }
      }
    }
  }
});

function* generatePiDigits() {
  let q = 1n, r = 180n, t = 60n, i = 2n;
  while (true) {
    let digit = ((i * 27n - 12n) * q + r * 5n) / (t * 5n);
    yield Number(digit);
    let u = i * 3n;
    u = (u + 1n) * 3n * (u + 2n);
    r = u * 10n * (q * (i * 5n - 2n) + r - t * digit);
    q *= 10n * i * (i++ * 2n - 1n);
    t *= u;
  }
}

const piDigitGenerator = generatePiDigits();

function updateChart() {
  if (!isRunning) return;
  
  const digit = piDigitGenerator.next().value;
  chartData[digit]++;
  piChart.data.datasets[0].data = chartData;
  piChart.update();
  
  animationFrame = requestAnimationFrame(updateChart);
}

document.getElementById('startBtn').addEventListener('click', () => {
  if (isRunning) return;
  isRunning = true;
  document.getElementById('pauseBtn').textContent = 'Pause';
  updateChart();
});

document.getElementById('pauseBtn').addEventListener('click', () => {
  isRunning = !isRunning;
  document.getElementById('pauseBtn').textContent = isRunning ? 'Pause' : 'Resume';
  if (isRunning) {
    updateChart();
  } else {
    cancelAnimationFrame(animationFrame);
  }
});